;; Copyright 1999 Profound Corp,  All Rights reserved
;; See licensing information for more details on usage rights


(setf title_screen      '("addon/twist/art/title.spe" . "title"))
(setf logo              '("addon/twist/art/title.spe" . "profound"))
(setq help_screens '("addon/twist/art/title.spe" "pro1" "pro2" "pro3" "pro4" "pro5"))
(setq sell_screens '(("addon/twist/art/title.spe" . "pro1")("addon/twist/art/title.spe" . "pro2")("addon/twist/art/title.spe" . "pro3")("addon/twist/art/title.spe" . "pro4")("addon/twist/art/title.spe" . "pro5")("art/fore/endgame.spe" . "credit")))

