;; Copyright 1997 Mike Moss (tfirestorm@aol.com),  All Rights reserved
;; See readme for more details on usage rights
;; blah blah yackety smackety

(load_tiles "addon/aliens/fortiles.spe"
	"addon/aliens/bactiles.spe")