;; Copyright 1999 Profound Corp,  All Rights reserved
;; See licensing information for more details on usage rights


(load "addon/twist/lisp/weapons.lsp")
(load "addon/twist/lisp/light.lsp")
(load "addon/twist/lisp/tiles.lsp")
(load "addon/twist/lisp/title.lsp")
(load "addon/twist/lisp/tints.lsp")
(load "addon/twist/lisp/ai.lsp")
(load "addon/twist/lisp/chars.lsp")
(load "addon/twist/lisp/players.lsp")
(load "addon/twist/lisp/chat.lsp")
(load "addon/twist/lisp/mario.lsp")