(select (random 4)
    (0 (setq net_levels
        '("netlevel/8play1.spe"
          "netlevel/8play2.spe"
          "netlevel/8play3.spe"
          "netlevel/8play4.spe"
          "netlevel/limeston.spe"
          "netlevel/bugs.spe"
          "netlevel/jdm3.spe")))
    (1 (setq net_levels
        '("netlevel/bugs.spe"
          "netlevel/8play3.spe"
          "netlevel/8play4.spe"
          "netlevel/8play1.spe"
          "netlevel/limeston.spe"
          "netlevel/8play2.spe"
          "netlevel/jdm3.spe")))
    (2 (setq net_levels
        '("netlevel/limeston.spe"
          "netlevel/8play4.spe"
          "netlevel/8play2.spe"
          "netlevel/jdm3.spe"
          "netlevel/8play1.spe"
          "netlevel/8play3.spe"
          "netlevel/bugs.spe")))
    (3 (setq net_levels
        '("netlevel/jdm3.spe"
          "netlevel/8play1.spe"
          "netlevel/8play4.spe"
          "netlevel/bugs.spe"
          "netlevel/8play2.spe"
          "netlevel/8play3.spe"
          "netlevel/limeston.spe"))))

