;; Loaded by fRaBs at startup, as of version 1.8

(load "addon/leon/lisp/nguns.lsp")
(load "addon/leon/lisp/lnant.lsp")
(load "addon/leon/lisp/lmisc.lsp")
(load "addon/leon/lisp/deco.lsp")
(load_tiles "addon/leon/lnewft.spe")
(load_tiles "addon/leon/lnewft2.spe")
