;; Copyright 1995 Crack dot Com,  All Rights reserved
;; See licensing information for more details on usage rights


(select language
	('english (setq gray_pick_message "Select the darkest gray visible on your monitor")))


